@@ -4,6 +4,7 @@ from curses.textpad import rectangle
 import curses
 
 def askyesno(stdscr,message: list = []) -> bool:
+    """Display a messagebox that asks a user a questions. Returns TRUE on Yes and FALSE on No. Colour is green"""
     selected = True
     x,y = os.get_terminal_size()
     ox = 0
@@ -16,15 +17,15 @@ def askyesno(stdscr,message: list = []) -> bool:
     while True:
         for by in range(y//2-(len(message)//2)-1,y//2+(len(message)//2)+4):
             for bx in range(x//2-(maxs//2)-1,x//2+(maxs//2+1)+1):
-                stdscr.addstr(by,bx," ",curses.color_pair(12))
+                stdscr.addstr(by,bx," ",cp.set_colour(cp.GREEN,cp.WHITE))
         rectangle(stdscr,y//2-(len(message)//2)-1, x//2-(maxs//2)-1, y//2+(len(message)//2)+4, x//2+(maxs//2+1)+1)
         stdscr.addstr(y//2+(len(message)//2)+4,x//2-(maxs//2),"Y: Yes | N: No")
         mi = -(len(message)/2)
-        stdscr.addstr(y//2+(len(message)//2)+3,x//2-(maxs//2),"[Yes]",[curses.color_pair(9) if selected else curses.color_pair(6)][0])
-        stdscr.addstr(y//2+(len(message)//2)+3,x//2-(maxs//2)+10,"[No]",[curses.color_pair(6) if selected else curses.color_pair(9)][0])   
+        stdscr.addstr(y//2+(len(message)//2)+3,x//2-(maxs//2),"[Yes]",[cp.set_colour(cp.WHITE,cp.BLACK) if selected else cp.set_colour(cp.BLACK,cp.WHITE)][0])
+        stdscr.addstr(y//2+(len(message)//2)+3,x//2-(maxs//2)+10,"[No]",[cp.set_colour(cp.BLACK,cp.WHITE) if selected else cp.set_colour(cp.WHITE,cp.BLACK)][0])   
         for msgl in message:
             mi += 1
-            stdscr.addstr(int(y//2+mi),int(x//2-len(msgl)//2),msgl,curses.color_pair(12))
+            stdscr.addstr(int(y//2+mi),int(x//2-len(msgl)//2),msgl,cp.set_colour(cp.GREEN,cp.WHITE))
     
         stdscr.refresh()
         
@@ -37,6 +38,7 @@ def askyesno(stdscr,message: list = []) -> bool:
             return selected
 
 def showinfo(stdscr,message: list = [],title:str="Info") -> None:
+    """Display a messagebox that shows info to a user. Background BLUE"""
     selected = True
     x,y = os.get_terminal_size()
     ox = 0
@@ -49,14 +51,14 @@ def showinfo(stdscr,message: list = [],title:str="Info") -> None:
     while True:
         for by in range(y//2-(len(message)//2)-1,y//2+(len(message)//2)+4):
             for bx in range(x//2-(maxs//2)-1,x//2+(maxs//2+1)+1):
-                stdscr.addstr(by,bx," ",curses.color_pair(10))
+                stdscr.addstr(by,bx," ",cp.set_colour(cp.BLUE,cp.WHITE))
         rectangle(stdscr,y//2-(len(message)//2)-1, x//2-(maxs//2)-1, y//2+(len(message)//2)+4, x//2+(maxs//2+1)+1)
         stdscr.addstr(y//2-(len(message)//2)-1, x//2-(maxs//2)-1,title)
         mi = -(len(message)/2)
-        stdscr.addstr(y//2+(len(message)//2)+3,x//2-(maxs//2),"[OK]",curses.color_pair(9)) 
+        stdscr.addstr(y//2+(len(message)//2)+3,x//2-(maxs//2),"[OK]",cp.set_colour(cp.WHITE,cp.BLACK)) 
         for msgl in message:
             mi += 1
-            stdscr.addstr(int(y//2+mi),int(x//2-len(msgl)//2),msgl,curses.color_pair(10))
+            stdscr.addstr(int(y//2+mi),int(x//2-len(msgl)//2),msgl,cp.set_colour(cp.BLUE,cp.WHITE))
     
         stdscr.refresh()
         
@@ -65,6 +67,7 @@ def showinfo(stdscr,message: list = [],title:str="Info") -> None:
             return
 
 def showwarning(stdscr,message: list = [],title:str="Warning") -> None:
+    """Display a messagebox that shows a warning to a user. Background YELLOW"""
     selected = True
     x,y = os.get_terminal_size()
     ox = 0
@@ -77,14 +80,14 @@ def showwarning(stdscr,message: list = [],title:str="Warning") -> None:
     while True:
         for by in range(y//2-(len(message)//2)-1,y//2+(len(message)//2)+4):
             for bx in range(x//2-(maxs//2)-1,x//2+(maxs//2+1)+1):
-                stdscr.addstr(by,bx," ",curses.color_pair(13))
+                stdscr.addstr(by,bx," ",cp.set_colour(cp.YELLOW,cp.WHITE))
         rectangle(stdscr,y//2-(len(message)//2)-1, x//2-(maxs//2)-1, y//2+(len(message)//2)+4, x//2+(maxs//2+1)+1)
         stdscr.addstr(y//2-(len(message)//2)-1, x//2-(maxs//2)-1,title)
         mi = -(len(message)/2)
-        stdscr.addstr(y//2+(len(message)//2)+3,x//2-(maxs//2),"[OK]",curses.color_pair(9)) 
+        stdscr.addstr(y//2+(len(message)//2)+3,x//2-(maxs//2),"[OK]",cp.set_colour(cp.WHITE,cp.BLACK)) 
         for msgl in message:
             mi += 1
-            stdscr.addstr(int(y//2+mi),int(x//2-len(msgl)//2),msgl,curses.color_pair(13))
+            stdscr.addstr(int(y//2+mi),int(x//2-len(msgl)//2),msgl,cp.set_colour(cp.YELLOW,cp.WHITE))
     
         stdscr.refresh()
         
@@ -93,6 +96,7 @@ def showwarning(stdscr,message: list = [],title:str="Warning") -> None:
             return
 
 def showerror(stdscr,message: list = [],title:str="Warning") -> None:
+    """Display a message to a user that shows an error. background red."""
     selected = True
     x,y = os.get_terminal_size()
     ox = 0
@@ -105,14 +109,14 @@ def showerror(stdscr,message: list = [],title:str="Warning") -> None:
     while True:
         for by in range(y//2-(len(message)//2)-1,y//2+(len(message)//2)+4):
             for bx in range(x//2-(maxs//2)-1,x//2+(maxs//2+1)+1):
-                stdscr.addstr(by,bx," ",curses.color_pair(11))
+                stdscr.addstr(by,bx," ",cp.set_colour(cp.RED,cp.WHITE))
         rectangle(stdscr,y//2-(len(message)//2)-1, x//2-(maxs//2)-1, y//2+(len(message)//2)+4, x//2+(maxs//2+1)+1)
         stdscr.addstr(y//2-(len(message)//2)-1, x//2-(maxs//2)-1,title)
         mi = -(len(message)/2)
-        stdscr.addstr(y//2+(len(message)//2)+3,x//2-(maxs//2),"[OK]",curses.color_pair(9)) 
+        stdscr.addstr(y//2+(len(message)//2)+3,x//2-(maxs//2),"[OK]",cp.set_colour(cp.WHITE,cp.BLACK)) 
         for msgl in message:
             mi += 1
-            stdscr.addstr(int(y//2+mi),int(x//2-len(msgl)//2),msgl,curses.color_pair(11))
+            stdscr.addstr(int(y//2+mi),int(x//2-len(msgl)//2),msgl,cp.set_colour(cp.RED,cp.WHITE))
     
         stdscr.refresh()
         
